# MCDPPY: Minecraft Datapack Python Library

This repository is intended to produce Minecraft Datapack with convenience.
Currently this library is mostly focused on functions but it's subject to change.
